@@ -1,11 +1,11 @@
 ########################################################################
-# Vers 2.01 5 May 2006, (c)2004-2006 John Lim (jlim#natsoft.com.my) All Rights Reserved
+# Vers 2.10 16 July 2008, (c)2004-2008 John Lim (jlim#natsoft.com) All Rights Reserved
 # Released under a BSD-style license. See LICENSE.txt.
 # Download: http://adodb.sourceforge.net/#pydownload
 ########################################################################
 
 __author__ = "John Lim (jlim#natsoft.com)"
-__credits__ = "(c) 2004-2006 John Lim"
+__credits__ = "(c) 2004-2008 John Lim"
 
 import exceptions,sys,re
 from datetime import datetime
@@ -252,7 +252,7 @@ class ADOConnection:
                 else:
                     print s;
             #if debug
-                    
+           
             if params == None: _cursor.execute(sql)
             else: _cursor.execute(sql,params)
             self._errormsg = ''
@@ -366,7 +366,7 @@ class ADOConnection:
     
     def Close(self):
         try:
-            if _self._conn != None: self._conn.close()
+            if self._conn != None: self._conn.close()
         except:
             pass
         
